input - GooeyPy Docs

Documentation
Overview
gui

- app
- widget
- styleset
- effects

widgets

- label
- button
- input
- slider
- container
- box
- selectbox
- textblock
- image

- Input
- Input.font

# Input

Input([value, [max_length, [disallowed_chars]]]) - Input widget

Creates an HTML like input field.

### Arguments

value
  The initial value of the input (defaults to ""). Note that due to the nature of the value, you cannot link to it (but you can from it). If you really want to link it's value you can do so it _value, but it may not always work like you expect!
max_length
  The maximum number of character that can be put into the Input.
disallowed_chars
  A list of characters that are disallowed to enter.

## Input.font

Input.font -> pygame.Font

The font that this input is using.